%global pkgname float

Name:           gap-pkg-%{pkgname}
Version:        0.7.4
Release:        1%{?dist}
Summary:        GAP access to mpfr, mpfi, mpc, fplll and cxsc

License:        GPLv3+
URL:            http://gap-packages.github.io/float/
Source0:        https://github.com/gap-packages/%{pkgname}/releases/download/v%{version}/%{pkgname}-%{version}.tar.gz

BuildRequires:  cxsc-devel
BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gcc-c++
BuildRequires:  libfplll-devel
BuildRequires:  libmpc-devel
BuildRequires:  mpfi-devel
BuildRequires:  mpfr-devel

Requires:       gap-core

%description
This package implements floating-point numbers within GAP, with
arbitrary precision, based on the C libraries FPLLL, MPFR, MPFI, MPC
and CXSC.

%prep
%setup -q -n %{pkgname}-%{version}

%build
# The __APPLE__ symbol actually guards an explicit template instantiation,
# which llvm needs, but our version of g++ also needs.
export CPPFLAGS="-I %{_includedir}/cxsc -D__APPLE__"
%configure --with-gaproot=%{_gap_dir}
make %{?_smp_mflags}

# Build the documentation
mkdir ../pkg
ln -s ../%{pkgname}-%{version} ../pkg
gap -l "$PWD/..;%{_gap_dir}" makedoc.g
rm -fr ../pkg

%install
%make_install

# We do not want the libtool archive
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/*/*.la

# Install the GAP files; we install test files for use by GAP's internal test
# suite runner.
cp -a *.g lib tst %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{lib,tst}/Makefile*

# Install the documentation
mkdir -p %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc
cp -p doc/*.{bib,css,html,js,lab,pdf,six,txt,xml} \
      %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc

%check
# Change from obsolete test method to modern method
sed -e '/ReadTest/s/);/, rec( compareFunction := "uptowhitespace" )&/' \
    -e 's/ReadTest/Test/' \
    -i tst/testall.g

gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" < tst/testall.g 2>&1 | tee log
grep -Fvq fail log
rm -f log

%files
%doc README THANKS
%license COPYING
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Fri Jul  1 2016 Jerry James <loganjerry@gmail.com> - 0.7.4-1
- Initial RPM
